@@ -15,7 +15,7 @@ use Crypt::Random qw( makerandom_octet );
 
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS $DEBUG);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our $DEBUG = 0;
 
@@ -81,7 +81,7 @@ sub new {
     my $enc_method = exists($params->{'data_enc_method'}) ? $params->{'data_enc_method'} : 'aes256-cbc';
     $self->{'data_enc_method'} = $self->_setEncryptionMethod($enc_method);
 
-    my $key_method = exists($params->{'key_transport'}) ? $params->{'key_transport'} : 'rsa-1_5';
+    my $key_method = exists($params->{'key_transport'}) ? $params->{'key_transport'} : 'rsa-oaep-mgf1p ';
     $self->{'key_transport'} = $self->_setKeyEncryptionMethod($key_method);
 
     return $self;
@@ -779,7 +779,7 @@ XML::Enc - XML::Enc Encryption Support
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -842,10 +842,16 @@ Used in encryption.  Optional.  Default method: aes256-cbc
 
 =item * L<aes128-cbc|https://www.w3.org/TR/2002/REC-xmlenc-core-20021210/Overview.html#aes128-cbc>
 
-=item * L<aes196-cbc|https://www.w3.org/TR/2002/REC-xmlenc-core-20021210/Overview.html#aes192-cbc>
+=item * L<aes192-cbc|https://www.w3.org/TR/2002/REC-xmlenc-core-20021210/Overview.html#aes192-cbc>
 
 =item * L<aes256-cbc|https://www.w3.org/TR/2002/REC-xmlenc-core-20021210/Overview.html#aes256-cbc>
 
+=item * L<aes128-gcm|https://www.w3.org/TR/xmlenc-core/#aes128-gcm>
+
+=item * L<aes192-gcm|https://www.w3.org/TR/xmlenc-core/#aes192-gcm>
+
+=item * L<aes256-gcm|https://www.w3.org/TR/xmlenc-core/#aes256-gcm>
+
 =back
 
 =item B<key_transport>
